//
//  TESTTextfieldView.m
//
//  Created by Thomas Wolters on 20/10/15.
//  Copyright © 2015 fluodmobile. All rights reserved.
//

#import "Demo2SpringView.h"
#import "TPKeyboardAvoidingScrollView.h"

@interface Demo2SpringView() <UITextFieldDelegate>

@property (nonatomic, strong) UITextField* textField;
@property (nonatomic, strong) UIButton* button;

@property (nonatomic, strong) TPKeyboardAvoidingScrollView* scrollView;
@end

@implementation Demo2SpringView

- (instancetype)init{
    self = [super init];
    if (!self) {
        return nil;
    }
    self.scrollView = [TPKeyboardAvoidingScrollView new];
    self.scrollView.userInteractionEnabled = YES;
    UITapGestureRecognizer* tapGesture = [[UITapGestureRecognizer alloc] initWithTarget:self action:@selector(actionHideKeyboard:)];
    [self.scrollView addGestureRecognizer:tapGesture];
    [self addSubview:self.scrollView];
    
    self.backgroundColor = [UIColor darkGrayColor];
    
    self.textField = [UITextField new];
    self.textField.backgroundColor = [UIColor lightGrayColor];
    self.textField.secureTextEntry = YES;
    self.textField.layer.cornerRadius = 5;
    [self.scrollView addSubview:self.textField];
    
    self.button = [UIButton new];
    [self.button setTitle:@"Verify" forState:UIControlStateNormal];
    [self.button addTarget:self action:@selector(actionTap:) forControlEvents:UIControlEventTouchUpInside];
    [self.button setTitleColor:[UIColor blackColor] forState:UIControlStateNormal];
    self.button.backgroundColor = [UIColor whiteColor];
    self.button.layer.cornerRadius = 5;
    self.button.layer.borderColor = [UIColor lightGrayColor].CGColor;
    self.button.layer.borderWidth = 2;
    [self.scrollView addSubview:self.button];
    self.textField.placeholder = @"Password";
    
    return self;
}

-(void)layoutSubviews{
    [super layoutSubviews];
    self.scrollView.frame = self.bounds;
    self.textField.frame = [self textFieldFrame];
    self.button.frame = (CGRect){50,self.bounds.size.height-120,self.bounds.size.width-100,50};
}

-(CGRect)textFieldFrame{
    return (CGRect){50,self.bounds.size.height-180,self.bounds.size.width-100,50};
}

-(void)actionTap:(id)sender{
    if ([self.textField.text isEqualToString:@"0000"]){
        self.textField.text = @"";
    }
    else{
        [self actionHideKeyboard:nil];

        CGRect frame = self.textField.frame;
        frame.origin.x -=4;
        frame.origin.y -=1;
        frame.size.width -=1;
        frame.size.height -=1;
        self.textField.frame = frame;
        [UIView animateWithDuration:1.0f delay:0.0f usingSpringWithDamping:.001f initialSpringVelocity:10000.0 options:UIViewAnimationOptionLayoutSubviews animations:^{
            self.textField.frame = [self textFieldFrame];
        } completion:^(BOOL complete){
            [self setNeedsLayout];
        }];
    }
}

-(void)actionHideKeyboard:(id)sender{
    [self.textField resignFirstResponder];
}

@end
